==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/TransactionStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TransactionStateDescription } from "./TransactionStateDescription";
/**
 * @hidden
 */
export let TransactionStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class TransactionStateDescriptionMetadata extends Base {
        static b(a) {
            if (TransactionStateDescriptionMetadata.a == null) {
                TransactionStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TransactionStateDescriptionMetadata.c(TransactionStateDescriptionMetadata.a);
            }
            if (a.j(TransactionStateDescriptionMetadata.a)) {
                return;
            }
            a.y(TransactionStateDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IdRef", "(w:ID,xam:ID,wf:ID)DataRef");
            a.item("TransactionType", "ExportedType:string:TransactionType");
            a.item("TransactionType@names", "Add;Update;Delete");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("VersionRef", "(w:Version,wf:Version)DataRef");
        }
        static d(a) {
            TransactionStateDescriptionMetadata.b(a);
            a.aa("TransactionState", () => new TransactionStateDescription());
            a.z("TransactionState", TransactionStateDescriptionMetadata.a);
        }
    }
    TransactionStateDescriptionMetadata.$t = /*@__PURE__*/ markType(TransactionStateDescriptionMetadata, 'TransactionStateDescriptionMetadata');
    TransactionStateDescriptionMetadata.a = null;
    return TransactionStateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TransactionStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TransactionStateDescription } from "./TransactionStateDescription";
/**
 * @hidden
 */
export let TransactionStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class TransactionStateDescriptionMetadata extends Base {
        static b(a) {
            if (TransactionStateDescriptionMetadata.a == null) {
                TransactionStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TransactionStateDescriptionMetadata.c(TransactionStateDescriptionMetadata.a);
            }
            if (a.k(TransactionStateDescriptionMetadata.a)) {
                return;
            }
            a.aa(TransactionStateDescriptionMetadata.a);
        }
        static c(a) {
            a.item("IdRef", "(w:ID,xam:ID,wf:ID)DataRef");
            a.item("TransactionType", "ExportedType:string:TransactionType");
            a.item("TransactionType@names", "Add;Update;Delete");
            a.item("ValueRef", "(w:Value,wf:Value)DataRef");
            a.item("VersionRef", "(w:Version,wf:Version)DataRef");
        }
        static d(a) {
            TransactionStateDescriptionMetadata.b(a);
            a.ac("TransactionState", () => new TransactionStateDescription());
            a.ab("TransactionState", TransactionStateDescriptionMetadata.a);
        }
    }
    TransactionStateDescriptionMetadata.$t = /*@__PURE__*/ markType(TransactionStateDescriptionMetadata, 'TransactionStateDescriptionMetadata');
    TransactionStateDescriptionMetadata.a = null;
    return TransactionStateDescriptionMetadata;
})();
